@@ -13,7 +13,8 @@ NULL
 #'   with_active_span
 NULL
 
-# For `otel::default_tracer_name()`
+# Fixed variable named required for `otel::default_tracer_name()`
+# which is used in `otel::get_tracer()` within `promises_otel_tracer()`
 otel_tracer_name <- "co.posit.r-package.promises"
 
 # Using local scope avoids an environment object lookup on each call.
@@ -23,7 +24,7 @@ testthat__is_testing <- function() {
   identical(Sys.getenv("TESTTHAT"), "true")
 }
 
-get_tracer <- local({
+promises_otel_tracer <- local({
   tracer <- NULL
   function() {
     if (!is.null(tracer)) {
@@ -39,7 +40,7 @@ get_tracer <- local({
   }
 })
 
-#' `r lifecycle::badge("experimental")` OpenTelemetry integration
+#' OpenTelemetry integration
 #'
 #' @description
 #' \pkg{otel} provides tools for integrating with OpenTelemetry, a framework for
@@ -48,7 +49,7 @@ get_tracer <- local({
 #' These methods are intended to enhance the framework to be used with the
 #' \pkg{promises} package, not as a generic replacement.
 #'
-#' Developer note - Barret 2025/09: This ospan handoff promise domain topic is
+#' Developer note - Barret 2025/09: This otel span handoff promise domain topic is
 #' complex and has been discussed over many hours. Many advanced Shiny/R
 #' developers are not even aware of promise domains (very reasonable!),
 #' therefore this topic requires more in-depth documentation and examples.
@@ -64,8 +65,8 @@ get_tracer <- local({
 #'   graphics device at each stage will only ever print to the most recently
 #'   created graphics device, not the associated graphics device. These promise
 #'   domains are not automatically created, they must be manually added to the
-#'   execution stack, for example `with_ospan_promise_domain()` does this for
-#'   OpenTelemetry spans ("ospan").
+#'   execution stack, for example `with_otel_promise_domain()` does this for
+#'   OpenTelemetry spans.
 #' * Promise domain restoration: When switching from one promise chain to
 #'   another, the execution context is torn down and then re-established. This
 #'   re-establishment is called "promise domain restoration". During this
@@ -82,29 +83,29 @@ get_tracer <- local({
 #'   objects. The only way the promise domain is captured is exactly when the
 #'   `then()` method is called.
 #'
-#' `with_ospan_promise_domain()` creates a promise domain that restores the
+#' `with_otel_promise_domain()` creates a promise domain that restores the
 #' currently active OpenTelemetry span from when a call to `promises::then()` is
-#' executed. Given the special circumstance where only the current ospan is
-#' needed to continue recording (not a full ancestry tree of ospans), we can
-#' capture _just_ the current ospan and reactivate that ospan during promise
+#' executed. Given the special circumstance where only the current otel span is
+#' needed to continue recording (not a full ancestry tree of otel spans), we can
+#' capture _just_ the current otel span and reactivate that otel span during promise
 #' domain restoration.
 #'
 #' @section When promise domains are captured:
 #'
 #' Asynchronous operation
-#' * Creates `async_op` ospan
-#' * Automatically ends the ospan (`async_op`) when the promise (p)
+#' * Creates `async_op` otel span
+#' * Automatically ends the otel span (`async_op`) when the promise (p)
 #'   resolves or rejects
 #'
 #' The code below illustrates an example of when the promise domain are
-#' created/captured/restored and when ospan objects are
+#' created/captured/restored and when otel span objects are
 #' created/activated/reactivated/ended.
 #'
 #' ```r
 #' # t0.0
-#' p2 <- with_ospan_promise_domain({
+#' p2 <- with_otel_promise_domain({
 #'   # t0.1
-#'   p <- with_ospan_async("async_op", {
+#'   p <- with_otel_span("async_op", {
 #'     # ... return a promise ...
 #'     init_async_work() |> # t0.2
 #'       then( # t0.3
@@ -125,36 +126,36 @@ get_tracer <- local({
 #'
 #' An in-depth explanation of the execution timeline is below.
 #' * At the first initial tick, `t0.*`:
-#'   * `t0.0`: The code is wrapped in `with_ospan_promise_domain()`
-#'   * `t0.1`: The `async_op` ospan is created and activated
+#'   * `t0.0`: The code is wrapped in `with_otel_promise_domain()`
+#'   * `t0.1`: The `async_op` otel span is created and activated
 #'   * `t0.2`: Some async work is initiated
-#'   * `t0.3`: `then()` is called, capturing the active `async_op` ospan (as it
-#'     is called within `with_ospan_promise_domain()`)
-#'   * `t0.4`: The `with_ospan_async()` call exits, but the `async_op` ospan is
+#'   * `t0.3`: `then()` is called, capturing the active `async_op` otel span (as it
+#'     is called within `with_otel_promise_domain()`)
+#'   * `t0.4`: The `with_otel_span()` call exits, but the `async_op` otel span is
 #'     not ended as the promise is still pending. The returned promise has a
-#'     `finally()` step added to it that will end the ospan `async_op` when `p`
+#'     `finally()` step added to it that will end the otel span `async_op` when `p`
 #'     is resolved.
-#'   * `t0.5`: Another `then()` is called, but there is no active ospan to
+#'   * `t0.5`: Another `then()` is called, but there is no active otel span to
 #'     capture
-#'   * `t0.6`: The ospan promise domain call exits
-#'   * `t0.7`: Another `then()` is called. No ospan will be captured as there is
-#'     no active ospan / promise domain
+#'   * `t0.6`: The otel span promise domain call exits
+#'   * `t0.7`: Another `then()` is called. No otel span will be captured as there is
+#'     no active otel span / promise domain
 #' * At the first followup tick, `t1.0`:
-#'   * The active `async_op` ospan is reactivated during promise domain
+#'   * The active `async_op` otel span is reactivated during promise domain
 #'     restoration for the duration of the `then` callback
 #'   * The `some_async_work` function is called
 #' * At tick, `t2.0`:
 #'   * `some_async_work` has resolved
-#'   * A hidden `finally()` step closes the ospan, `async_op`
+#'   * A hidden `finally()` step closes the otel span, `async_op`
 #'   * `p` is now resolved
 #' * At tick, `t3.0`:
-#'   * There is no active ospan at `t0.5`, so no ospan is reactivated during
+#'   * There is no active otel span at `t0.5`, so no otel span is reactivated during
 #'     promise domain restoration
 #'   * The `more_async_work` function is executed
 #' * At tick, `t4.0`:
 #'   * `more_async_work` has resolved, therefore `p2` is now resolved
-#'   * There was no ospan promise domain at `t0.7`, so no attempt is made to
-#'     reactivate any ospan
+#'   * There was no otel span promise domain at `t0.7`, so no attempt is made to
+#'     reactivate any otel span
 #'   * The `final_work` function is executed
 #' * At tick, `t5.0`:
 #'   * `p_final` has resolved
@@ -163,65 +164,63 @@ get_tracer <- local({
 #' @section Complexity:
 #'
 #' When reactivating the `k`th step in a promise chain, the currently active
-#' ospan (during the call to `then()`) will be reactivated during promise domain
-#' restoration (`O(1)`). To restore a chain of promises, the active ospan will
+#' otel span (during the call to `then()`) will be reactivated during promise domain
+#' restoration (`O(1)`). To restore a chain of promises, the active otel span will
 #' be restored at each step (`O(n)`) due to the **`n`** calls to wrapping each
 #' `onFulfilled` and `onRejected` callbacks inside `then()`.
 #'
-#' If we did NOT have a handoff promise domain for ospan restoration, a regular
+#' If we did NOT have a handoff promise domain for otel span restoration, a regular
 #' promise domain approach would be needed at each step to restore the active
-#' ospan. Each step would call `with_active_span()` `k` times (`O(k)`, where as
-#' handoff domain computes in `O(1)`). Taking a step back, to restore each ospan
+#' otel span. Each step would call `with_active_span()` `k` times (`O(k)`, where as
+#' handoff domain computes in `O(1)`). Taking a step back, to restore each otel span
 #' at for every step in a promise chain would then take `O(n^2)` time, not
 #' `O(n)`. The standard, naive promise domain approach does not scale for
 #' multiple similar promise domain restorations.
 #'
 #'
-#' @section Execution model for `with_ospan_promise_domain()`:
+#' @section Execution model for `with_otel_promise_domain()`:
 #'
-#' 1. `with_ospan_promise_domain(expr)` is called.
+#' 1. `with_otel_promise_domain(expr)` is called.
 #'    * The following steps all occur within `expr`.
-#' 2. Create an ospan object using `otel::start_span()`.
-#'    * We need the ospan to be active during the a followup async operation.
+#' 2. Create an otel span object using `otel::start_span()`.
+#'    * We need the otel span to be active during the a followup async operation.
 #'      Therefore, `otel::start_local_active_span()` is not appropriate as the
-#'      ospan would be ended when the function exits, not when the promise chain
+#'      otel span would be ended when the function exits, not when the promise chain
 #'      resolves.
-#' 2. Be sure your ospan is activated before calling `promises::then()`.
-#'    * Activate it using `with_ospan_async(name, expr)` (which also
-#'      creates/ends the ospan) or `otel::with_active_span(span, expr)`.
+#' 2. Be sure your otel span is activated before calling `promises::then()`.
+#'    * Activate it using `with_otel_span(name, expr)` (which also
+#'      creates/ends the otel span) or `otel::with_active_span(span, expr)`.
 #' 3. Call `promises::then()`
 #'   * When `promises::then()` is called, the two methods (`onFulfilled` and
 #'     `onRejected`) capture the currently active spans. (Performed by the
-#'     initial `with_ospan_promise_domain()`)
+#'     initial `with_otel_promise_domain()`)
 #' 4. During reactivation of the promise chain step, the previously captured
-#'    ospan is reactivated via `with_active_span()`. (Performed by the initial
-#'    `with_ospan_promise_domain()`)
+#'    otel span is reactivated via `with_active_span()`. (Performed by the initial
+#'    `with_otel_promise_domain()`)
 #'
 #' @section OpenTelemetry span compatibility:
 #'
-#' For ospan objects to exist over may async ticks, the ospan must be created
+#' For otel span objects to exist over may async ticks, the otel span must be created
 #' using `otel::start_span()` and later ended using `otel::end_span()`. Ending
-#' the ospan must occur **after** any promise chain work has completed.
+#' the otel span must occur **after** any promise chain work has completed.
 #'
-#' If we were to instead use `otel::start_local_active_span()`, the ospan would
+#' If we were to instead use `otel::start_local_active_span()`, the otel span would
 #' be ended when the function exits, not when the promise chain completes. Even
-#' though the local ospan is created, activated, and eventually ended, the ospan
-#' will not exist during reactivation of the ospan promise domain.
+#' though the local otel span is created, activated, and eventually ended, the otel span
+#' will not exist during reactivation of the otel span promise domain.
 #'
-#' `with_ospan_async()` is a convenience method that creates, activates, and
-#' ends the ospan only after the returned promise (if any) resolves. It also
-#' properly handles both synchronous (ending the ospan within `on.exit()`) and
-#' asynchronous operations (ending the ospan within `promises::finally()`).
+#' `with_otel_span()` is a convenience method that creates, activates, and
+#' ends the otel span only after the returned promise (if any) resolves. It also
+#' properly handles both synchronous (ending the otel span within `on.exit()`) and
+#' asynchronous operations (ending the otel span within `promises::finally()`).
 #'
 #'
 #'
 #'
-#' @describeIn otel `r lifecycle::badge("experimental")`
-#'
-#' Creates an OpenTelemetry span, executes the given expression within it, and
+#' @describeIn otel Creates an OpenTelemetry span, executes the given expression within it, and
 #' ends the span.
 #'
-#' This method **requires** the use of `with_ospan_promise_domain()`
+#' This method **requires** the use of `with_otel_promise_domain()`
 #' to be within the execution stack.
 #'
 #' This function is designed to handle both synchronous and asynchronous
@@ -240,8 +239,8 @@ get_tracer <- local({
 #' If OpenTelemetry is not enabled, the expression will be evaluated without any
 #' tracing context.
 #'
-#' @param name Character string. The name of the ospan.
-#' @param expr An expression to evaluate within the ospan context.
+#' @param name Character string. The name of the otel span.
+#' @param expr An expression to evaluate within the otel span context.
 #' @param ... Additional arguments passed to [`otel::start_span()`].
 #' @param tracer (Required) An `{otel}` tracer. It is required to provide your
 #'   own tracer from your own package. See [`otel::get_tracer()`] for more
@@ -254,27 +253,27 @@ get_tracer <- local({
 #' @examples
 #' \dontrun{
 #' # Common usage:
-#' with_ospan_promise_domain({
+#' with_otel_promise_domain({
 #'   # ... deep inside some code execution ...
 #'
-#'   # Many calls to `with_ospan_async()` within `with_ospan_promise_domain()`
-#'   with_ospan_async("my_operation", {
+#'   # Many calls to `with_otel_span()` within `with_otel_promise_domain()`
+#'   with_otel_span("my_operation", {
 #'     # ... do some work ...
 #'   })
 #' })
 #' }
 #' \dontrun{
-#' with_ospan_promise_domain({
+#' with_otel_promise_domain({
 #'   # ... deep inside some code execution ...
 #'
 #'   # Synchronous operation
 #'   # * Creates `my_operation` span
-#'   result <- with_ospan_async("my_operation", {
+#'   result <- with_otel_span("my_operation", {
 #'     # ... do some work ...
 #'     print(otel::get_active_span()$name) # "my_operation"
 #'
 #'     # Nest (many) more spans
-#'     prom_nested <- with_ospan_async("my_nested_operation", {
+#'     prom_nested <- with_otel_span("my_nested_operation", {
 #'       # ... do some more work ...
 #'       promise_resolve(42) |>
 #'         then(\(value) {
@@ -299,7 +298,7 @@ get_tracer <- local({
 #'   })
 #' })
 #' }
-with_ospan_async <- function(
+with_otel_span <- function(
   name,
   expr,
   ...,
@@ -346,14 +345,12 @@ with_ospan_async <- function(
 }
 
 
-#' @describeIn otel `r lifecycle::badge("experimental")`
-#'
-#' Adds an idempotent handoff Active OpenTelemetry span promise domain.
+#' @describeIn otel Adds an idempotent handoff Active OpenTelemetry span promise domain.
 #'
 #' Package authors are required to use this function to have otel span context
 #' persist across asynchronous boundaries. This method is only needed once per
 #' promise domain stack. If you are unsure, feel free to call
-#' `with_ospan_promise_domain()` as the underlying promise domain will only be
+#' `with_otel_promise_domain()` as the underlying promise domain will only be
 #' added if not found within the current promise domain stack. If your package
 #' **only** works within Shiny apps, Shiny will have already added the domain so
 #' no need to add it yourself. If your package works outside of Shiny and you
@@ -362,45 +359,46 @@ with_ospan_async <- function(
 #'
 #' This method adds a _handoff_ Active OpenTelemetry span promise domain to the
 #' expression evaluation. This _handoff_ promise domain will only run once on
-#' reactivation. This is critical if there are many layered `with_ospan_async()`
-#' calls, such as within Shiny reactivity. For example, if we nested many
-#' `with_ospan_async()` of which each added a promise domain that reactivated
-#' each ospan on restore, we'd reactivate `k` ospan objects (`O(k)`) when we
-#' only need to activate the **last** span (`O(1)`).
+#' reactivation. This is critical if there are many layered
+#' `with_otel_span()` calls, such as within Shiny reactivity. For example, if
+#' we nested many `with_otel_span()` calls of which each call added a promise
+#' domain that reactivated each otel span on restore, we'd reactivate `k` otel
+#' span objects (`O(k)`) when we only need to activate the **last** span
+#' (`O(1)`).
 #'
-#' Returns the result of evaluating `expr` within the ospan promise domain.
+#' Returns the result of evaluating `expr` within the otel span promise domain.
 #'
 #' @export
-with_ospan_promise_domain <- function(expr) {
-  # Do not add the ospan handoff promise domain twice
-  if (has_ospan_promise_domain()) {
+with_otel_promise_domain <- function(expr) {
+  # with_otel_promise_domain <- function(expr) {
+  # Do not add the otel span handoff promise domain twice
+  if (has_otel_promise_domain()) {
     return(force(expr))
   }
-  act_span_pd <- create_ospan_promise_domain()
+  act_span_pd <- create_otel_promise_domain()
   with_promise_domain(act_span_pd, expr)
 }
 
 
-#' @describeIn otel `r lifecycle::badge("experimental")`
-#'
-#' Local OpenTelemetry span promise domain
+#' @describeIn otel Local OpenTelemetry span promise domain
 #'
 #' Adds an OpenTelemetry span promise domain to the local scope. This is useful
 #' for `{coro}` operations where encapsulating the coro operations inside a
 #' `with_*()` methods is not allowed.
 #'
-#' When not using `{coro}`, please prefer to use `with_ospan_async()` or
-#' `with_ospan_promise_domain()`.
+#' When not using `{coro}`, please prefer to use `with_otel_span()` or
+#' `with_otel_promise_domain()`.
 #' @export
 #' @param envir The "local" environment in which to add the promise domain. When
 #' the environment is exited, the promise domain is removed.
-local_ospan_promise_domain <- function(envir = parent.frame()) {
-  if (has_ospan_promise_domain()) {
+local_otel_promise_domain <- function(envir = parent.frame()) {
+  # local_otel_promise_domain <- function(envir = parent.frame()) {
+  if (has_otel_promise_domain()) {
     return(invisible())
   }
 
   local_promise_domain(
-    create_ospan_promise_domain(),
+    create_otel_promise_domain(),
     envir = envir
   )
 }
@@ -431,16 +429,16 @@ local_promise_domain <- function(
 
 # # TODO: Set attributes on the current active span
 # # 5. Set attributes on the current active span
-# set_ospan_attrs(status = 200L)
+# set_otel_span_attrs(status = 200L)
 
 # -- Helpers --------------------------------------------------------------
 
-has_ospan_promise_domain <- function(domain = current_promise_domain()) {
+has_otel_promise_domain <- function(domain = current_promise_domain()) {
   # Works for:
   # * `list()` `compose_domains()` result
   # * `NULL` - current_promise_domain() init value
   # * environment objects - `new_promise_domain()` result
-  isTRUE(domain[[".ospan_promise_domain"]])
+  isTRUE(domain[[".otel_promise_domain"]])
 }
 
 #' Create a OpenTelemetry handoff promise domain
@@ -450,9 +448,9 @@ has_ospan_promise_domain <- function(domain = current_promise_domain()) {
 #'
 #' @param span An OpenTelemetry span object.
 #' @noRd
-create_ospan_promise_domain <- function() {
+create_otel_promise_domain <- function() {
   new_promise_domain(
-    .ospan_promise_domain = TRUE, # set flag for later discovery
+    .otel_promise_domain = TRUE, # set flag for later discovery
     wrapOnFulfilled = function(onFulfilled) {
       force(onFulfilled)
 
