@@ -1,11 +1,10 @@
 skip_on_cran()
+skip_on_os("mac") # TODO: Remove this skip once paralely is fixed on macOS in GHA; https://github.com/futureverse/doFuture/issues/87#issuecomment-3001858683
 skip_on_os("windows") # timing is not consistent on Windows GHA
 
 skip_if_not_installed("future", "1.21.0")
 skip_if_not_installed("fastmap", "1.1.0")
 
-source(test_path("common.R"))
-
 local({
   ## Setup ##
 
@@ -13,7 +12,7 @@ local({
   # Set up a plan with 2 future workers
   with_test_workers <- function(code) {
     # (Can not use a variable for workers if in a local({}))
-    old_plan <- future::plan(future::multisession(workers = 2))
+    old_plan <- future::plan(future::multisession, workers = 2)
     on.exit(
       {
         future::plan(old_plan)
@@ -41,7 +40,9 @@ local({
   # We should expect to see `run_every()` statements interleaved with `future_promise()` calls
   # We should NOT expect to see `run_every()` statements while `future::future()` is blocking the main R session
   run_every <- function(i = 0, max = 2 / delay, delay = 0.1) {
-    if (i > max) return()
+    if (i > max) {
+      return()
+    }
     time_diffs <<- c(time_diffs, time_diff())
     # Do it again, later
     later::later(
@@ -94,10 +95,10 @@ local({
               future::future({
                 Sys.sleep(worker_job_time)
                 time_diff()
-              }) %...>%
-                {
-                  future_exec_times <<- c(future_exec_times, .)
-                }
+              }) |>
+                then(\(x) {
+                  future_exec_times <<- c(future_exec_times, x)
+                })
             },
             delay = 1
           )
@@ -105,19 +106,22 @@ local({
       }
 
       exec_times <- NA
-      p <- lapply(seq_len(worker_jobs), function(i) {
-        prom_fn({
-          Sys.sleep(worker_job_time)
-          time_diff()
+      proms <-
+        lapply(seq_len(worker_jobs), function(i) {
+          prom_fn({
+            Sys.sleep(worker_job_time)
+            time_diff()
+          })
+        })
+
+      p <-
+        promise_all(.list = proms) |>
+        then(\(x) {
+          exec_times <<- unlist(x)
         })
-      }) %>%
-        promise_all(.list = .) %...>%
-        {
-          exec_times <<- unlist(.)
-        }
       post_lapply_time_diff <- time_diff()
 
-      p %>% wait_for_it()
+      p |> wait_for_it()
 
       # expect that the average time is less than the expected total time
       expect_equal(median(exec_times) < expected_total_time, !block_mid_session)
@@ -197,11 +201,10 @@ local({
   test_that("future_promise doesn't report errors that have been handled", {
     with_test_workers({
       err <- capture.output(type = "message", {
-        future_promise(stop("boom1")) %>%
+        future_promise(stop("boom1")) |>
           then(
-            onRejected = ~ {
-            }
-          ) %>%
+            onRejected = \(err) {}
+          ) |>
           wait_for_it()
       })
       expect_equal(err, character(0))
